@@ -1,7 +1,10 @@
 
-__version__ = '0.0.1'
+__version__ = '0.0.2'
 
 # all functions are accessible from upper level,
 #  since their dissociation into files are often not relevant for user.
+from .fief import filter_effective_parameters as fief
+from .random import *
 from .kotlin import *
 from .itermore import *
+from .confiseur import Confiseur, Bonbon
